
Welcome to WalT integrated help.

# User documentation

## Getting started

In order to get familiar with main WalT concepts, see [`walt help show tutorial`](tutorial.md).

## General concepts

### Node-related terminology

To understand why a given user owns a given node or not, and for related aspects of terminology, see [`walt help show node-terminology`](node-terminology.md).

### Working with shells

WalT provides:
* direct access to nodes (using `walt node shell`)
* access to the underlying operating system image (using `walt image shell`)

If you are not sure when to use which command, see [`walt help show shells`](shells.md).

### Log management

WalT provides a logging system to manage your experiment logs.
See [`walt help show logging`](logging.md) for more info.

## Advanced users

For specific needs, it is possible to build your own WalT image from scratch.
See [`walt help show image-from-scratch`](image-from-scratch.md) for more info.
